? primary.patch
Index: includes/menu.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/menu.inc,v
retrieving revision 1.275
diff -u -p -r1.275 menu.inc
--- includes/menu.inc	12 Jun 2008 20:49:39 -0000	1.275
+++ includes/menu.inc	18 Jun 2008 14:33:29 -0000
@@ -1251,28 +1251,28 @@ function menu_get_names($reset = FALSE) 
  * Return an array containing the names of system-defined (default) menus.
  */
 function menu_list_system_menus() {
-  return array('navigation', 'primary-links', 'secondary-links');
+  return array('navigation', 'main-menu', 'secondary-menu');
 }
 
 /**
- * Return an array of links to be rendered as the Primary links.
+ * Return an array of links to be rendered as the Main menu.
  */
-function menu_primary_links() {
-  return menu_navigation_links(variable_get('menu_primary_links_source', 'primary-links'));
+function menu_main_menu() {
+  return menu_navigation_links(variable_get('menu_main_menu_source', 'main-menu'));
 }
 
 /**
  * Return an array of links to be rendered as the Secondary links.
  */
-function menu_secondary_links() {
+function menu_secondary_menu() {
 
   // If the secondary menu source is set as the primary menu, we display the
   // second level of the primary menu.
-  if (variable_get('menu_secondary_links_source', 'secondary-links') == variable_get('menu_primary_links_source', 'primary-links')) {
-    return menu_navigation_links(variable_get('menu_primary_links_source', 'primary-links'), 1);
+  if (variable_get('menu_secondary_menu_source', 'secondary-menu') == variable_get('menu_main_menu_source', 'main-menu')) {
+    return menu_navigation_links(variable_get('menu_main_menu_source', 'main-menu'), 1);
   }
   else {
-    return menu_navigation_links(variable_get('menu_secondary_links_source', 'secondary-links'), 0);
+    return menu_navigation_links(variable_get('menu_secondary_menu_source', 'secondary-menu'), 0);
   }
 }
 
Index: includes/theme.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/theme.inc,v
retrieving revision 1.426
diff -u -p -r1.426 theme.inc
--- includes/theme.inc	6 Jun 2008 01:50:20 -0000	1.426
+++ includes/theme.inc	18 Jun 2008 14:33:29 -0000
@@ -864,8 +864,8 @@ function theme_get_settings($key = NULL)
     'logo_path'                     =>  '',
     'default_favicon'               =>  1,
     'favicon_path'                  =>  '',
-    'primary_links'                 =>  1,
-    'secondary_links'               =>  1,
+    'main_menu'                     =>  1,
+    'secondary_menu'                =>  1,
     'toggle_logo'                   =>  1,
     'toggle_favicon'                =>  1,
     'toggle_name'                   =>  1,
@@ -874,8 +874,8 @@ function theme_get_settings($key = NULL)
     'toggle_mission'                =>  1,
     'toggle_node_user_picture'      =>  0,
     'toggle_comment_user_picture'   =>  0,
-    'toggle_primary_links'          =>  1,
-    'toggle_secondary_links'        =>  1,
+    'toggle_main_menu'              =>  1,
+    'toggle_secondary_menu'         =>  1,
   );
 
   if (module_exists('node')) {
@@ -1838,8 +1838,8 @@ function template_preprocess_page(&$vari
   $variables['logo']              = theme_get_setting('logo');
   $variables['messages']          = $variables['show_messages'] ? theme('status_messages') : '';
   $variables['mission']           = isset($mission) ? $mission : '';
-  $variables['primary_links']     = theme_get_setting('toggle_primary_links') ? menu_primary_links() : array();
-  $variables['secondary_links']   = theme_get_setting('toggle_secondary_links') ? menu_secondary_links() : array();
+  $variables['main_menu']         = theme_get_setting('toggle_main_menu') ? menu_main_menu() : array();
+  $variables['secondary_menu']    = theme_get_setting('toggle_secondary_menu') ? menu_secondary_menu() : array();
   $variables['search_box']        = (theme_get_setting('toggle_search') ? drupal_get_form('search_theme_form') : '');
   $variables['site_name']         = (theme_get_setting('toggle_name') ? variable_get('site_name', 'Drupal') : '');
   $variables['site_slogan']       = (theme_get_setting('toggle_slogan') ? variable_get('site_slogan', '') : '');
Index: includes/theme.maintenance.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/theme.maintenance.inc,v
retrieving revision 1.13
diff -u -p -r1.13 theme.maintenance.inc
--- includes/theme.maintenance.inc	28 Apr 2008 09:25:26 -0000	1.13
+++ includes/theme.maintenance.inc	18 Jun 2008 14:33:29 -0000
@@ -252,8 +252,8 @@ function template_preprocess_maintenance
   $variables['logo']              = theme_get_setting('logo');
   $variables['messages']          = $variables['show_messages'] ? theme('status_messages') : '';
   $variables['mission']           = '';
-  $variables['primary_links']     = array();
-  $variables['secondary_links']   = array();
+  $variables['main_menu']         = array();
+  $variables['secondary_menu']    = array();
   $variables['search_box']        = '';
   $variables['site_name']         = (theme_get_setting('toggle_name') ? variable_get('site_name', 'Drupal') : '');
   $variables['site_slogan']       = (theme_get_setting('toggle_slogan') ? variable_get('site_slogan', '') : '');
Index: modules/menu/menu.admin.inc
===================================================================
RCS file: /cvs/drupal/drupal/modules/menu/menu.admin.inc,v
retrieving revision 1.30
diff -u -p -r1.30 menu.admin.inc
--- modules/menu/menu.admin.inc	14 Apr 2008 17:48:37 -0000	1.30
+++ modules/menu/menu.admin.inc	18 Jun 2008 14:33:29 -0000
@@ -607,30 +607,30 @@ function menu_configure() {
   $form['menu_default_node_menu'] = array(
     '#type' => 'select',
     '#title' => t('Default menu for content'),
-    '#default_value' => variable_get('menu_default_node_menu', 'primary-links'),
+    '#default_value' => variable_get('menu_default_node_menu', 'main-menu'),
     '#options' => $menu_options,
     '#description' => t('Choose the menu to be the default in the menu options in the content authoring form.'),
   );
 
-  $primary = variable_get('menu_primary_links_source', 'primary-links');
-  $primary_options = array_merge($menu_options, array('' => t('No primary links')));
-  $form['menu_primary_links_source'] = array(
+  $main = variable_get('menu_main_menu_source', 'main-menu');
+  $main_options = array_merge($menu_options, array('' => t('No Main menu')));
+  $form['menu_main_menu_source'] = array(
     '#type' => 'select',
-    '#title' => t('Source for the primary links'),
-    '#default_value' => $primary,
-    '#options' => $primary_options,
+    '#title' => t('Source for the Main menu'),
+    '#default_value' => $main,
+    '#options' => $main_options,
     '#tree' => FALSE,
-    '#description' => t('Select what should be displayed as the primary links.'),
+    '#description' => t('Select what should be displayed as the Main menu.'),
   );
 
-  $secondary_options = array_merge($menu_options, array('' => t('No secondary links')));
-  $form["menu_secondary_links_source"] = array(
+  $secondary_options = array_merge($menu_options, array('' => t('No Secondary menu')));
+  $form["menu_secondary_menu_source"] = array(
     '#type' => 'select',
-    '#title' => t('Source for the secondary links'),
-    '#default_value' => variable_get('menu_secondary_links_source', 'secondary-links'),
+    '#title' => t('Source for the Secondary menu'),
+    '#default_value' => variable_get('menu_secondary_menu_source', 'secondary-menu'),
     '#options' => $secondary_options,
     '#tree' => FALSE,
-    '#description' => t('Select what should be displayed as the secondary links. You can choose the same menu for secondary links as for primary links (currently %primary). If you do this, the children of the active primary menu link will be displayed as secondary links.', array('%primary' => $primary_options[$primary])),
+    '#description' => t("Select the source for the Secondary menu. An advanced option allows you to use the same source for both Main menu (currently %main) and Secondary menu: if your source menu has two levels of hierarchy, the top level menu items will appear in the Main menu, and the children of the active item will appear in the Secondary menu." , array('%main' => $main_options[$main])),
   );
 
   return system_settings_form($form);
Index: modules/menu/menu.install
===================================================================
RCS file: /cvs/drupal/drupal/modules/menu/menu.install,v
retrieving revision 1.11
diff -u -p -r1.11 menu.install
--- modules/menu/menu.install	14 Mar 2008 08:54:31 -0000	1.11
+++ modules/menu/menu.install	18 Jun 2008 14:33:29 -0000
@@ -10,8 +10,8 @@ function menu_install() {
 
   $t = get_t();
   db_query("INSERT INTO {menu_custom} (menu_name, title, description) VALUES ('%s', '%s', '%s')", 'navigation', $t('Navigation'), $t('The navigation menu is provided by Drupal and is the main interactive menu for any site. It is usually the only menu that contains personalized links for authenticated users, and is often not even visible to anonymous users.'));
-  db_query("INSERT INTO {menu_custom} (menu_name, title, description) VALUES ('%s', '%s', '%s')", 'primary-links', $t('Primary links'), $t('Primary links are often used at the theme layer to show the major sections of a site. A typical representation for primary links would be tabs along the top.'));
-  db_query("INSERT INTO {menu_custom} (menu_name, title, description) VALUES ('%s', '%s', '%s')", 'secondary-links', $t('Secondary links'), $t('Secondary links are often used for pages like legal notices, contact details, and other secondary navigation items that play a lesser role than primary links.'));
+  db_query("INSERT INTO {menu_custom} (menu_name, title, description) VALUES ('%s', '%s', '%s')", 'main-menu', $t('Main menu'), $t('The Main menu is often used by themes to show the major sections of a site. A typical representation of the Main menu would be tabs along the top.'));
+  db_query("INSERT INTO {menu_custom} (menu_name, title, description) VALUES ('%s', '%s', '%s')", 'secondary-menu', $t('Secondary menu'), $t('The Secondary menu is often used for pages like legal notices, contact details, and other navigation items that play a lesser role than the Main menu.'));
 }
 
 /**
@@ -28,7 +28,7 @@ function menu_uninstall() {
  */
 function menu_schema() {
   $schema['menu_custom'] = array(
-    'description' => t('Holds definitions for top-level custom menus (for example, Primary Links).'),
+    'description' => t('Holds definitions for top-level custom menus (for example, Main menu).'),
     'fields' => array(
       'menu_name' => array(
         'type' => 'varchar',
Index: modules/menu/menu.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/menu/menu.module,v
retrieving revision 1.164
diff -u -p -r1.164 menu.module
--- modules/menu/menu.module	10 May 2008 06:52:32 -0000	1.164
+++ modules/menu/menu.module	18 Jun 2008 14:33:29 -0000
@@ -18,7 +18,7 @@ define('MENU_MAX_MENU_NAME_LENGTH_UI', 2
 function menu_help($path, $arg) {
   switch ($path) {
     case 'admin/help#menu':
-      $output = '<p>' . t("The menu module provides an interface to control and customize Drupal's powerful menu system. Menus are a hierarchical collection of links, or menu items, used to navigate a website, and are positioned and displayed using Drupal's flexible block system. By default, three menus are created during installation: <em>Navigation</em>, <em>Primary links</em>, and <em>Secondary links</em>. The <em>Navigation</em> menu contains most links necessary for working with and navigating your site, and is often displayed in either the left or right sidebar. Most Drupal themes also provide support for <em>Primary links</em> and <em>Secondary links</em>, by displaying them in either the header or footer of each page. By default, <em>Primary links</em> and <em>Secondary links</em> contain no menu items but may be configured to contain custom menu items specific to your site.") . '</p>';
+      $output = '<p>' . t("The menu module provides an interface to control and customize Drupal's powerful menu system. Menus are a hierarchical collection of links, or menu items, used to navigate a website, and are positioned and displayed using Drupal's flexible block system. By default, three menus are created during installation: <em>Navigation</em>, <em>Main menu</em>, and <em>Secondary menu</em>. The <em>Navigation</em> menu contains most links necessary for working with and navigating your site, and is often displayed in either the left or right sidebar. Most Drupal themes also provide support for the <em>Main menu</em> and <em>Secondary menu</em>, by displaying them in either the header or footer of each page. By default, the <em>Main menu</em> and <em>Secondary menu</em> contain no menu items but may be configured to contain custom menu items specific to your site.") . '</p>';
       $output .= '<p>' . t('The <a href="@menu">menus page</a> displays all menus currently available on your site. Select a menu from this list to add or edit a menu item, or to rearrange items within the menu. Create new menus using the <a href="@add-menu">add menu page</a> (the block containing a new menu must also be enabled on the <a href="@blocks">blocks administration page</a>).', array('@menu' => url('admin/build/menu'), '@add-menu' => url('admin/build/menu/add'), '@blocks' => url('admin/build/block'))) . '</p>';
       $output .= '<p>' . t('For more information, see the online handbook entry for <a href="@menu">Menu module</a>.', array('@menu' => 'http://drupal.org/handbook/modules/menu/')) . '</p>';
       return $output;
@@ -48,7 +48,7 @@ function menu_perm() {
 function menu_menu() {
   $items['admin/build/menu'] = array(
     'title' => 'Menus',
-    'description' => "Control your site's navigation menu, primary links and secondary links. as well as rename and reorganize menu items.",
+    'description' => "Control your site's Navigation menu, Main menu and Secondary menu. as well as rename and reorganize menu items.",
     'page callback' => 'menu_overview_page',
     'access callback' => 'user_access',
     'access arguments' => array('administer menu'),
@@ -310,7 +310,7 @@ function menu_nodeapi(&$node, $op) {
     case 'prepare':
       if (empty($node->menu)) {
         // Prepare the node for the edit form so that $node->menu always exists.
-        $menu_name = variable_get('menu_default_node_menu', 'primary-links');
+        $menu_name = variable_get('menu_default_node_menu', 'main-menu');
         $item = array();
         if (isset($node->nid)) {
           // Give priority to the default menu
@@ -387,7 +387,7 @@ function menu_form_alter(&$form, $form_s
     $options = menu_parent_options(menu_get_menus(), $item);
     $default = $item['menu_name'] . ':' . $item['plid'];
     if (!isset($options[$default])) {
-      $default = 'primary-links:0';
+      $default = 'main-menu:0';
     }
     $form['menu']['parent'] = array(
       '#type' => 'select',
Index: modules/system/system.admin.inc
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/system.admin.inc,v
retrieving revision 1.76
diff -u -p -r1.76 system.admin.inc
--- modules/system/system.admin.inc	10 May 2008 07:32:02 -0000	1.76
+++ modules/system/system.admin.inc	18 Jun 2008 14:33:30 -0000
@@ -370,8 +370,8 @@ function system_theme_settings(&$form_st
     'comment_user_picture' => t('User pictures in comments'),
     'search'               => t('Search box'),
     'favicon'              => t('Shortcut icon'),
-    'primary_links'        => t('Primary links'),
-    'secondary_links'      => t('Secondary links'),
+    'main_menu'            => t('Main menu'),
+    'secondary_menu'      => t('Secondary menu'),
   );
 
   // Some features are not always available
Index: modules/system/system.install
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/system.install,v
retrieving revision 1.254
diff -u -p -r1.254 system.install
--- modules/system/system.install	15 May 2008 20:55:58 -0000	1.254
+++ modules/system/system.install	18 Jun 2008 14:33:30 -0000
@@ -3018,6 +3018,18 @@ function system_update_7008() {
 }
 
 /**
+ * Rename the variables for primary and secondary links.
+ *
+ */
+function system_update_7009() {
+  $ret = array();
+  $ret[] = update_sql("UPDATE {variable} SET name = 'menu_main_menu_source' WHERE name = 'menu_primary_links_source'");
+  $ret[] = update_sql("UPDATE {variable} SET name = 'menu_secondary_menu_source' WHERE name = 'menu_secondary_links_source'");
+
+  return $ret;
+}
+
+/**
  * @} End of "defgroup updates-6.x-to-7.x"
  * The next series of updates should start at 8000.
  */
Index: modules/system/system.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/system.module,v
retrieving revision 1.602
diff -u -p -r1.602 system.module
--- modules/system/system.module	7 May 2008 19:17:50 -0000	1.602
+++ modules/system/system.module	18 Jun 2008 14:33:31 -0000
@@ -928,8 +928,8 @@ function system_theme_default() {
       'node_user_picture',
       'search',
       'slogan',
-      'primary_links',
-      'secondary_links',
+      'main_menu',
+      'secondary_menu',
     ),
     'stylesheets' => array(
       'all' => array('style.css')
Index: themes/bluemarine/page.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/themes/bluemarine/page.tpl.php,v
retrieving revision 1.29
diff -u -p -r1.29 page.tpl.php
--- themes/bluemarine/page.tpl.php	7 May 2008 07:05:56 -0000	1.29
+++ themes/bluemarine/page.tpl.php	18 Jun 2008 14:33:31 -0000
@@ -19,8 +19,8 @@
     <?php if ($site_slogan) { ?><div class='site-slogan'><?php print $site_slogan ?></div><?php } ?>
 
     <div id="menu">
-      <?php if (isset($secondary_links)) { ?><?php print theme('links', $secondary_links, array('class' => 'links', 'id' => 'subnavlist')); ?><?php } ?>
-      <?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links, array('class' => 'links', 'id' => 'navlist')) ?><?php } ?>
+      <?php if (isset($secondary_menu)) { ?><?php print theme('links', $secondary_menu, array('class' => 'links', 'id' => 'subnavlist')); ?><?php } ?>
+      <?php if (isset($main_menu)) { ?><?php print theme('links', $main_menu, array('class' => 'links', 'id' => 'navlist')) ?><?php } ?>
     </div>
 
     <div id="header-region"><?php print $header ?></div>
Index: themes/chameleon/chameleon.theme
===================================================================
RCS file: /cvs/drupal/drupal/themes/chameleon/chameleon.theme,v
retrieving revision 1.77
diff -u -p -r1.77 chameleon.theme
--- themes/chameleon/chameleon.theme	14 Apr 2008 17:48:44 -0000	1.77
+++ themes/chameleon/chameleon.theme	18 Jun 2008 14:33:31 -0000
@@ -50,15 +50,15 @@ function chameleon_page($content, $show_
 
   $output .= "</div>\n";
 
-  $primary_links = theme('links', menu_primary_links(), array('class' => 'links', 'id' => 'navlist'));
-  $secondary_links = theme('links', menu_secondary_links(), array('class' => 'links', 'id' => 'subnavlist'));
-  if (isset($primary_links) || isset($secondary_links)) {
+  $main_menu = theme('links', menu_main_menu(), array('class' => 'links', 'id' => 'navlist'));
+  $secondary_menu = theme('links', menu_secondary_menu(), array('class' => 'links', 'id' => 'subnavlist'));
+  if (isset($main_menu) || isset($secondary_menu)) {
     $output .= ' <div class="navlinks">';
-    if (isset($primary_links)) {
-      $output .= $primary_links;
+    if (isset($main_menu)) {
+      $output .= $main_menu;
     }
-    if (isset($secondary_links)) {
-      $output .= $secondary_links;
+    if (isset($secondary_menu)) {
+      $output .= $secondary_menu;
     }
     $output .= " </div>\n";
   }
Index: themes/garland/print.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/print.css,v
retrieving revision 1.6
diff -u -p -r1.6 print.css
--- themes/garland/print.css	28 Apr 2008 09:25:27 -0000	1.6
+++ themes/garland/print.css	18 Jun 2008 14:33:31 -0000
@@ -7,7 +7,7 @@ body, input, textarea, select {
   font-size: 11pt;
 }
 
-ul.primary-links, ul.secondary-links,
+ul.main-menu, ul.secondary-menu,
 #header-region, .sidebar {
   display: none;
 }
Index: themes/garland/style-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style-rtl.css,v
retrieving revision 1.9
diff -u -p -r1.9 style-rtl.css
--- themes/garland/style-rtl.css	10 Apr 2008 10:28:23 -0000	1.9
+++ themes/garland/style-rtl.css	18 Jun 2008 14:33:31 -0000
@@ -129,24 +129,24 @@ dl dd {
 /**
  * Primary navigation
  */
-ul.primary-links {
+ul.main-menu {
   float: left;
 width:70%;
 }
 
-ul.primary-links li {
+ul.main-menu li {
   float: right;
 }
 
 /**
  * Secondary navigation
  */
-ul.secondary-links {
+ul.secondary-menu {
   float: left;
   clear: left;
 }
 
-ul.secondary-links li {
+ul.secondary-menu li {
   float: right;
 }
 
Index: themes/garland/style.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style.css,v
retrieving revision 1.45
diff -u -p -r1.45 style.css
--- themes/garland/style.css	5 May 2008 21:10:48 -0000	1.45
+++ themes/garland/style.css	18 Jun 2008 14:33:31 -0000
@@ -545,7 +545,7 @@ body.two-sidebars #footer {
 /**
  * Primary navigation
  */
-ul.primary-links {
+ul.main-menu {
   margin: 0;
   padding: 0;
   float: right; /* LTR */
@@ -553,14 +553,14 @@ ul.primary-links {
   z-index: 4;
 }
 
-ul.primary-links li {
+ul.main-menu li {
   margin: 0;
   padding: 0;
   float: left; /* LTR */
   background-image: none;
 }
 
-ul.primary-links li a, ul.primary-links li a:link, ul.primary-links li a:visited {
+ul.main-menu li a, ul.main-menu li a:link, ul.main-menu li a:visited {
   display: block;
   margin: 0 1em;
   padding: .75em 0 0;
@@ -568,7 +568,7 @@ ul.primary-links li a, ul.primary-links 
   background: transparent url(images/bg-navigation-item.png) no-repeat 50% 0;
 }
 
-ul.primary-links li a:hover, ul.primary-links li a.active {
+ul.main-menu li a:hover, ul.main-menu li a.active {
   color: #fff;
   background: transparent url(images/bg-navigation-item-hover.png) no-repeat 50% 0;
 }
@@ -576,7 +576,7 @@ ul.primary-links li a:hover, ul.primary-
 /**
  * Secondary navigation
  */
-ul.secondary-links {
+ul.secondary-menu {
   margin: 0;
   padding: 18px 0 0;
   float: right; /* LTR */
@@ -585,14 +585,14 @@ ul.secondary-links {
   z-index: 4;
 }
 
-ul.secondary-links li {
+ul.secondary-menu li {
   margin: 0;
   padding: 0;
   float: left; /* LTR */
   background-image: none;
 }
 
-ul.secondary-links li a, ul.secondary-links li a:link, ul.secondary-links li a:visited {
+ul.secondary-menu li a, ul.secondary-menu li a:link, ul.secondary-menu li a:visited {
   display: block;
   margin: 0 1em;
   padding: .75em 0 0;
@@ -600,7 +600,7 @@ ul.secondary-links li a, ul.secondary-li
   background: transparent;
 }
 
-ul.secondary-links li a:hover, ul.secondary-links li a.active {
+ul.secondary-menu li a:hover, ul.secondary-menu li a.active {
   color: #cde3f1;
   background: transparent;
 }
Index: themes/garland/template.php
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/template.php,v
retrieving revision 1.18
diff -u -p -r1.18 template.php
--- themes/garland/template.php	28 Apr 2008 09:25:27 -0000	1.18
+++ themes/garland/template.php	18 Jun 2008 14:33:31 -0000
@@ -31,8 +31,8 @@ function garland_comment_wrapper($conten
  */
 function garland_preprocess_page(&$vars) {
   $vars['tabs2'] = menu_secondary_local_tasks();
-  $vars['primary_nav'] = isset($vars['primary_links']) ? theme('links', $vars['primary_links'], array('class' => 'links primary-links')) : FALSE;
-  $vars['secondary_nav'] = isset($vars['secondary_links']) ? theme('links', $vars['secondary_links'], array('class' => 'links secondary-links')) : FALSE;
+  $vars['primary_nav'] = isset($vars['main_menu']) ? theme('links', $vars['main_menu'], array('class' => 'links main-menu')) : FALSE;
+  $vars['secondary_nav'] = isset($vars['secondary_menu']) ? theme('links', $vars['secondary_menu'], array('class' => 'links secondary-menu')) : FALSE;
   $vars['ie_styles'] = garland_get_ie_styles();
 
   // Prepare header
Index: themes/pushbutton/page.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/themes/pushbutton/page.tpl.php,v
retrieving revision 1.25
diff -u -p -r1.25 page.tpl.php
--- themes/pushbutton/page.tpl.php	24 Jan 2008 09:42:53 -0000	1.25
+++ themes/pushbutton/page.tpl.php	18 Jun 2008 14:33:31 -0000
@@ -14,7 +14,7 @@
 
 <div class="hide"><a href="#content" title="<?php print t('Skip navigation') ?>." accesskey="2"><?php print t('Skip navigation') ?></a>.</div>
 
-<table id="primary-menu" summary="Navigation elements." border="0" cellpadding="0" cellspacing="0" width="100%">
+<table id="main-menu" summary="Navigation elements." border="0" cellpadding="0" cellspacing="0" width="100%">
   <tr>
     <td id="home" width="10%">
       <?php if ($logo) : ?>
@@ -30,16 +30,16 @@
         <div class='site-slogan'><?php print($site_slogan) ?></div>
       <?php endif;?>
     </td>
-    <td class="primary-links" width="70%" align="center" valign="middle">
-      <?php print theme('links', $primary_links, array('class' => 'links', 'id' => 'navlist')) ?>
+    <td class="main-menu" width="70%" align="center" valign="middle">
+      <?php print theme('links', $main_menu, array('class' => 'links', 'id' => 'navlist')) ?>
     </td>
   </tr>
 </table>
 
 <table id="secondary-menu" summary="Navigation elements." border="0" cellpadding="0" cellspacing="0" width="100%">
   <tr>
-    <td class="secondary-links" width="75%"  align="center" valign="middle">
-      <?php print theme('links', $secondary_links, array('class' => 'links', 'id' => 'subnavlist')) ?>
+    <td class="secondary-menu" width="75%"  align="center" valign="middle">
+      <?php print theme('links', $secondary_menu, array('class' => 'links', 'id' => 'subnavlist')) ?>
     </td>
     <td width="25%" align="center" valign="middle">
       <?php print $search_box ?>
@@ -100,11 +100,11 @@
 <table id="footer-menu" summary="Navigation elements." border="0" cellpadding="0" cellspacing="0" width="100%">
   <tr>
     <td align="center" valign="middle">
-    <?php if (isset($primary_links)) : ?>
-      <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
+    <?php if (isset($main_menu)) : ?>
+      <?php print theme('links', $main_menu, array('class' => 'links main-menu')) ?>
     <?php endif; ?>
-    <?php if (isset($secondary_links)) : ?>
-      <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
+    <?php if (isset($secondary_menu)) : ?>
+      <?php print theme('links', $secondary_menu, array('class' => 'links secondary-links')) ?>
     <?php endif; ?>
     </td>
   </tr>
Index: themes/pushbutton/style-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/pushbutton/style-rtl.css,v
retrieving revision 1.4
diff -u -p -r1.4 style-rtl.css
--- themes/pushbutton/style-rtl.css	25 Jan 2008 21:20:26 -0000	1.4
+++ themes/pushbutton/style-rtl.css	18 Jun 2008 14:33:31 -0000
@@ -11,7 +11,7 @@ blockquote {
   text-align: right;
 }
 
-#primary-menu tr {
+#main-menu tr {
   background: transparent url(header-a.jpg) right bottom repeat;
 }
 
@@ -27,7 +27,7 @@ td#home a:hover img {
   background: transparent url(logo-hover-rtl.jpg) repeat;
 }
 
-#primary-menu .primary-links {
+#main-menu .main-menu {
   background: transparent url(header-b-rtl.jpg) right top no-repeat;
 }
 
@@ -41,7 +41,7 @@ ul.links li {
   border-left: none;
 }
 
-#subnavlist li, ul.primary-links li, ul.secondary-links li {
+#subnavlist li, ul.main-menu li, ul.secondary-menu li {
   border-right: 1px solid #fff;
   border-left: none;
 }
Index: themes/pushbutton/style.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/pushbutton/style.css,v
retrieving revision 1.24
diff -u -p -r1.24 style.css
--- themes/pushbutton/style.css	22 Dec 2007 23:24:26 -0000	1.24
+++ themes/pushbutton/style.css	18 Jun 2008 14:33:32 -0000
@@ -75,12 +75,12 @@ pre {
 /*
 ** Page layout blocks / IDs
 */
-#primary-menu {
+#main-menu {
   border-collapse: separate;
   background-color: #e0edfb;
   border-bottom: 3px solid #69c;
 }
-#primary-menu tr {
+#main-menu tr {
   background: transparent url(header-a.jpg) left bottom repeat; /* LTR */
 }
 td#home {
@@ -96,17 +96,17 @@ td#home a:hover img {
   width: 144px;
   height: 63px;
 }
-.primary-links, .primary-links a:link, .primary-links a:visited {
+.main-menu, .main-menu a:link, .main-menu a:visited {
   color: #369;
 }
-.primary-links a:hover {
+.main-menu a:hover {
   color: #000;
 }
-#primary-menu .primary-links {
+#main-menu .main-menu {
   background: transparent url(header-b.jpg) left top no-repeat; /* LTR */
   font-size: 0.79em;
 }
-#primary-menu .primary-links h1, #primary-menu .primary-links h2, #primary-menu .primary-links h3 {
+#main-menu .main-menu h1, #main-menu .main-menu h2, #main-menu .main-menu h3 {
   font-size: 2.3em;
   color: #369;
 }
@@ -115,14 +115,14 @@ td#home a:hover img {
   background-color: #369;
   border-bottom: 3px solid #69c;
 }
-.secondary-links, .secondary-links a:link, .secondary-links a:visited {
+.secondary-menu, .secondary-menu a:link, .secondary-menu a:visited {
   color: #e4e9eb;
 }
-.secondary-links a:hover {
+.secondary-menu a:hover {
   color: #fff;
   text-decoration: underline;
 }
-#secondary-menu .secondary-links {
+#secondary-menu .secondary-menu {
   font-size: 0.85em;
 }
 ul.links li {
@@ -131,7 +131,7 @@ ul.links li {
 #navlist li {
   border-left: 1px solid #369; /* LTR */
 }
-#subnavlist li, ul.primary-links li, ul.secondary-links li {
+#subnavlist li, ul.main-menu li, ul.secondary-menu li {
   border-left: 1px solid #fff; /* LTR */
 }
 #navlist li.first, #subnavlist li.first, ul.links li.first {
@@ -330,14 +330,14 @@ table#footer-menu {
   padding: 5px;
   font-size: 0.75em;
 }
-#footer-menu .primary-links, #footer-menu a:link, #footer-menu a:visited {
+#footer-menu .main-menu, #footer-menu a:link, #footer-menu a:visited {
   color: #e4e9eb;
 }
 #footer-menu a:hover {
   color: #fff;
   text-decoration: underline;
 }
-#footer-menu .primary-links h1, #footer-menu .primary-links h2, #footer-menu .primary-links h3 {
+#footer-menu .main-menu h1, #footer-menu .main-menu h2, #footer-menu .main-menu h3 {
   font-size: 1.3em;
   color: #e4e9eb;
 }

Index: modules/system/page.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/page.tpl.php,v
retrieving revision 1.11
diff -u -p -r1.11 page.tpl.php
--- modules/system/page.tpl.php	24 Jan 2008 09:42:51 -0000	1.11
+++ modules/system/page.tpl.php	18 Jun 2008 14:33:29 -0000
@@ -45,9 +45,9 @@
  *
  * Navigation:
  * - $search_box: HTML to display the search box, empty if search has been disabled.
  * - $primary_links (array): An array containing primary navigation links for the
  *   site, if they have been configured.
  * - $secondary_links (array): An array containing secondary navigation links for
  *   the site, if they have been configured.
  *
  * Page content (in order of occurrance in the default page.tpl.php):
@@ -124,16 +124,16 @@
 
     <div id="container" class="clear-block">
 
-      <div id="navigation" class="menu <?php if (!empty($primary_links)) { print "withprimary"; } if (!empty($secondary_links)) { print " withsecondary"; } ?> ">
-        <?php if (!empty($primary_links)): ?>
-          <div id="primary" class="clear-block">
-            <?php print theme('links', $primary_links, array('class' => 'links primary-links')); ?>
+      <div id="navigation" class="menu <?php if (!empty($main_menu)) { print "withmain"; } if (!empty($secondary_menu)) { print " withsecondary"; } ?> ">
+        <?php if (!empty($main_menu)): ?>
+          <div id="main-menu" class="clear-block">
+            <?php print theme('links', $main_menu, array('class' => 'links main-menu')); ?>
           </div>
         <?php endif; ?>
 
-        <?php if (!empty($secondary_links)): ?>
-          <div id="secondary" class="clear-block">
-            <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')); ?>
+        <?php if (!empty($secondary_menu)): ?>
+          <div id="secondary-menu" class="clear-block">
+            <?php print theme('links', $secondary_menu, array('class' => 'links secondary-menu')); ?>
           </div>
         <?php endif; ?>
       </div> <!-- /navigation -->
@@ -45,9 +45,9 @@
  * Navigation:
  * - $search_box: HTML to display the search box, empty if search has been disabled.
- * - $primary_links (array): An array containing primary navigation links for the
+ * - $main_menu (array): An array containing the Main menu links for the
  *   site, if they have been configured.
@@ -45,9 +45,9 @@
  *   site, if they have been configured.
- * - $secondary_links (array): An array containing secondary navigation links for
+ * - $secondary_menu (array): An array containing the Secondary menu links for
  *   the site, if they have been configured.
  *